@@ -9,7 +9,7 @@ use v5.10;
 use strict;
 use warnings;
 
-use List::AllUtils qw(any last_value max part sum);
+use List::AllUtils qw(last_value max part sum);
 use List::UtilsBy qw(max_by min_by);
 use Piper::Path;
 use Scalar::Util qw(weaken);
@@ -25,7 +25,7 @@ use overload (
     fallback => 1,
 );
 
-our $VERSION = '0.03'; # from Piper-0.03.tar.gz
+our $VERSION = '0.04'; # from Piper-0.04.tar.gz
 
 #pod =head1 ATTRIBUTES
 #pod
@@ -210,9 +210,15 @@ for my $attr (qw(batch_size debug enabled verbose)) {
 sub has_pending {
     my ($self) = @_;
 
-    return $self->has_children
-        ? any { $_->has_pending } @{$self->children}
-        : $self->queue->ready;
+    if ($self->has_children) {
+        for my $child (@{$self->children}) {
+            return 1 if $child->has_pending;
+        }
+        return 0;
+    }
+    else {
+        return $self->queue->ready;
+    }
 }
 
 #pod =head2 *dequeue([$num])
@@ -1083,7 +1089,7 @@ It first attempts to choose the full-batch segment (C<< pending >= batch_size >>
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
